@@ -584,7 +584,10 @@ class OpenAssessmentBlock(MessageMixin,
             context_dict,
             initialize_js_func='CourseOpenResponsesListingBlock',
             additional_css=["static/css/lib/backgrid/backgrid%s.css" % min_postfix],
-            additional_js=["static/js/lib/backgrid/backgrid%s.js" % min_postfix]
+            additional_js=["static/js/lib/backgrid/backgrid%s.js" % min_postfix],
+            additional_js_context={
+                "ENHANCED_STAFF_GRADER": self.is_enhanced_staff_grader_enabled
+            }
         )
 
     def grade_available_responses_view(self, context=None):  # pylint: disable=unused-argument
